"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .reasoningsummarytext import ReasoningSummaryText, ReasoningSummaryTextTypedDict
from .reasoningtextcontent import ReasoningTextContent, ReasoningTextContentTypedDict
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import validate_open_enum
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


OpenResponsesReasoningType = Literal["reasoning",]


OpenResponsesReasoningStatusInProgress = Literal["in_progress",]


OpenResponsesReasoningStatusIncomplete = Literal["incomplete",]


OpenResponsesReasoningStatusCompleted = Literal["completed",]


OpenResponsesReasoningStatusUnionTypedDict = TypeAliasType(
    "OpenResponsesReasoningStatusUnionTypedDict",
    Union[
        OpenResponsesReasoningStatusCompleted,
        OpenResponsesReasoningStatusIncomplete,
        OpenResponsesReasoningStatusInProgress,
    ],
)


OpenResponsesReasoningStatusUnion = TypeAliasType(
    "OpenResponsesReasoningStatusUnion",
    Union[
        OpenResponsesReasoningStatusCompleted,
        OpenResponsesReasoningStatusIncomplete,
        OpenResponsesReasoningStatusInProgress,
    ],
)


OpenResponsesReasoningFormat = Union[
    Literal[
        "unknown",
        "openai-responses-v1",
        "xai-responses-v1",
        "anthropic-claude-v1",
    ],
    UnrecognizedStr,
]


class OpenResponsesReasoningTypedDict(TypedDict):
    r"""Reasoning output item with signature and format extensions"""

    type: OpenResponsesReasoningType
    id: str
    summary: List[ReasoningSummaryTextTypedDict]
    content: NotRequired[List[ReasoningTextContentTypedDict]]
    encrypted_content: NotRequired[Nullable[str]]
    status: NotRequired[OpenResponsesReasoningStatusUnionTypedDict]
    signature: NotRequired[Nullable[str]]
    format_: NotRequired[Nullable[OpenResponsesReasoningFormat]]


class OpenResponsesReasoning(BaseModel):
    r"""Reasoning output item with signature and format extensions"""

    type: OpenResponsesReasoningType

    id: str

    summary: List[ReasoningSummaryText]

    content: Optional[List[ReasoningTextContent]] = None

    encrypted_content: OptionalNullable[str] = UNSET

    status: Optional[OpenResponsesReasoningStatusUnion] = None

    signature: OptionalNullable[str] = UNSET

    format_: Annotated[
        Annotated[
            OptionalNullable[OpenResponsesReasoningFormat],
            PlainValidator(validate_open_enum(False)),
        ],
        pydantic.Field(alias="format"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "content",
            "encrypted_content",
            "status",
            "signature",
            "format",
        ]
        nullable_fields = ["encrypted_content", "signature", "format"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatmessagecontentitemtext import (
    ChatMessageContentItemText,
    ChatMessageContentItemTextTypedDict,
)
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


SystemMessageContentTypedDict = TypeAliasType(
    "SystemMessageContentTypedDict",
    Union[str, List[ChatMessageContentItemTextTypedDict]],
)


SystemMessageContent = TypeAliasType(
    "SystemMessageContent", Union[str, List[ChatMessageContentItemText]]
)


class SystemMessageTypedDict(TypedDict):
    content: SystemMessageContentTypedDict
    role: Literal["system"]
    name: NotRequired[str]


class SystemMessage(BaseModel):
    content: SystemMessageContent

    ROLE: Annotated[
        Annotated[Literal["system"], AfterValidator(validate_const("system"))],
        pydantic.Field(alias="role"),
    ] = "system"

    name: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ResponsesFormatTextType = Literal["text",]


class ResponsesFormatTextTypedDict(TypedDict):
    r"""Plain text response format"""

    type: ResponsesFormatTextType


class ResponsesFormatText(BaseModel):
    r"""Plain text response format"""

    type: ResponsesFormatTextType



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .websearchstatus import WebSearchStatus
from openrouter.types import BaseModel
from openrouter.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


ResponsesOutputItemFileSearchCallType = Literal["file_search_call",]


class ResponsesOutputItemFileSearchCallTypedDict(TypedDict):
    type: ResponsesOutputItemFileSearchCallType
    id: str
    queries: List[str]
    status: WebSearchStatus


class ResponsesOutputItemFileSearchCall(BaseModel):
    type: ResponsesOutputItemFileSearchCallType

    id: str

    queries: List[str]

    status: Annotated[WebSearchStatus, PlainValidator(validate_open_enum(False))]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List
from typing_extensions import NotRequired, TypedDict


class ListProvidersDataTypedDict(TypedDict):
    name: str
    r"""Display name of the provider"""
    slug: str
    r"""URL-friendly identifier for the provider"""
    privacy_policy_url: Nullable[str]
    r"""URL to the provider's privacy policy"""
    terms_of_service_url: NotRequired[Nullable[str]]
    r"""URL to the provider's terms of service"""
    status_page_url: NotRequired[Nullable[str]]
    r"""URL to the provider's status page"""


class ListProvidersData(BaseModel):
    name: str
    r"""Display name of the provider"""

    slug: str
    r"""URL-friendly identifier for the provider"""

    privacy_policy_url: Nullable[str]
    r"""URL to the provider's privacy policy"""

    terms_of_service_url: OptionalNullable[str] = UNSET
    r"""URL to the provider's terms of service"""

    status_page_url: OptionalNullable[str] = UNSET
    r"""URL to the provider's status page"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["terms_of_service_url", "status_page_url"]
        nullable_fields = [
            "privacy_policy_url",
            "terms_of_service_url",
            "status_page_url",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ListProvidersResponseTypedDict(TypedDict):
    r"""Returns a list of providers"""

    data: List[ListProvidersDataTypedDict]


class ListProvidersResponse(BaseModel):
    r"""Returns a list of providers"""

    data: List[ListProvidersData]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .endpointstatus import EndpointStatus
from .parameter import Parameter
from .providername import ProviderName
from openrouter.types import BaseModel, Nullable, UNSET_SENTINEL, UnrecognizedStr
from openrouter.utils import validate_open_enum
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import Any, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class PricingTypedDict(TypedDict):
    prompt: Any
    r"""A value in string or number format that is a large number"""
    completion: Any
    r"""A value in string or number format that is a large number"""
    request: NotRequired[Any]
    r"""A value in string or number format that is a large number"""
    image: NotRequired[Any]
    r"""A value in string or number format that is a large number"""
    image_output: NotRequired[Any]
    r"""A value in string or number format that is a large number"""
    audio: NotRequired[Any]
    r"""A value in string or number format that is a large number"""
    input_audio_cache: NotRequired[Any]
    r"""A value in string or number format that is a large number"""
    web_search: NotRequired[Any]
    r"""A value in string or number format that is a large number"""
    internal_reasoning: NotRequired[Any]
    r"""A value in string or number format that is a large number"""
    input_cache_read: NotRequired[Any]
    r"""A value in string or number format that is a large number"""
    input_cache_write: NotRequired[Any]
    r"""A value in string or number format that is a large number"""
    discount: NotRequired[float]


class Pricing(BaseModel):
    prompt: Any
    r"""A value in string or number format that is a large number"""

    completion: Any
    r"""A value in string or number format that is a large number"""

    request: Optional[Any] = None
    r"""A value in string or number format that is a large number"""

    image: Optional[Any] = None
    r"""A value in string or number format that is a large number"""

    image_output: Optional[Any] = None
    r"""A value in string or number format that is a large number"""

    audio: Optional[Any] = None
    r"""A value in string or number format that is a large number"""

    input_audio_cache: Optional[Any] = None
    r"""A value in string or number format that is a large number"""

    web_search: Optional[Any] = None
    r"""A value in string or number format that is a large number"""

    internal_reasoning: Optional[Any] = None
    r"""A value in string or number format that is a large number"""

    input_cache_read: Optional[Any] = None
    r"""A value in string or number format that is a large number"""

    input_cache_write: Optional[Any] = None
    r"""A value in string or number format that is a large number"""

    discount: Optional[float] = None


PublicEndpointQuantization = Union[
    Literal[
        "int4",
        "int8",
        "fp4",
        "fp6",
        "fp8",
        "fp16",
        "bf16",
        "fp32",
        "unknown",
    ],
    UnrecognizedStr,
]


class PublicEndpointTypedDict(TypedDict):
    r"""Information about a specific model endpoint"""

    name: str
    model_name: str
    context_length: float
    pricing: PricingTypedDict
    provider_name: ProviderName
    tag: str
    quantization: Nullable[PublicEndpointQuantization]
    max_completion_tokens: Nullable[float]
    max_prompt_tokens: Nullable[float]
    supported_parameters: List[Parameter]
    uptime_last_30m: Nullable[float]
    supports_implicit_caching: bool
    status: NotRequired[EndpointStatus]


class PublicEndpoint(BaseModel):
    r"""Information about a specific model endpoint"""

    name: str

    model_name: str

    context_length: float

    pricing: Pricing

    provider_name: Annotated[ProviderName, PlainValidator(validate_open_enum(False))]

    tag: str

    quantization: Annotated[
        Nullable[PublicEndpointQuantization], PlainValidator(validate_open_enum(False))
    ]

    max_completion_tokens: Nullable[float]

    max_prompt_tokens: Nullable[float]

    supported_parameters: List[
        Annotated[Parameter, PlainValidator(validate_open_enum(False))]
    ]

    uptime_last_30m: Nullable[float]

    supports_implicit_caching: bool

    status: Annotated[
        Optional[EndpointStatus], PlainValidator(validate_open_enum(True))
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["status"]
        nullable_fields = [
            "quantization",
            "max_completion_tokens",
            "max_prompt_tokens",
            "uptime_last_30m",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


Parameter = Union[
    Literal[
        "temperature",
        "top_p",
        "top_k",
        "min_p",
        "top_a",
        "frequency_penalty",
        "presence_penalty",
        "repetition_penalty",
        "max_tokens",
        "logit_bias",
        "logprobs",
        "top_logprobs",
        "seed",
        "response_format",
        "structured_outputs",
        "stop",
        "tools",
        "tool_choice",
        "parallel_tool_calls",
        "include_reasoning",
        "reasoning",
        "web_search_options",
        "verbosity",
    ],
    UnrecognizedStr,
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel, Nullable, UNSET_SENTINEL, UnrecognizedStr
from openrouter.utils import FieldMetadata, QueryParamMetadata, validate_open_enum
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import Literal, Union
from typing_extensions import Annotated, TypedDict


class GetGenerationRequestTypedDict(TypedDict):
    id: str


class GetGenerationRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]


APIType = Union[
    Literal[
        "completions",
        "embeddings",
    ],
    UnrecognizedStr,
]
r"""Type of API used for the generation"""


class GetGenerationDataTypedDict(TypedDict):
    r"""Generation data"""

    id: str
    r"""Unique identifier for the generation"""
    upstream_id: Nullable[str]
    r"""Upstream provider's identifier for this generation"""
    total_cost: float
    r"""Total cost of the generation in USD"""
    cache_discount: Nullable[float]
    r"""Discount applied due to caching"""
    upstream_inference_cost: Nullable[float]
    r"""Cost charged by the upstream provider"""
    created_at: str
    r"""ISO 8601 timestamp of when the generation was created"""
    model: str
    r"""Model used for the generation"""
    app_id: Nullable[float]
    r"""ID of the app that made the request"""
    streamed: Nullable[bool]
    r"""Whether the response was streamed"""
    cancelled: Nullable[bool]
    r"""Whether the generation was cancelled"""
    provider_name: Nullable[str]
    r"""Name of the provider that served the request"""
    latency: Nullable[float]
    r"""Total latency in milliseconds"""
    moderation_latency: Nullable[float]
    r"""Moderation latency in milliseconds"""
    generation_time: Nullable[float]
    r"""Time taken for generation in milliseconds"""
    finish_reason: Nullable[str]
    r"""Reason the generation finished"""
    tokens_prompt: Nullable[float]
    r"""Number of tokens in the prompt"""
    tokens_completion: Nullable[float]
    r"""Number of tokens in the completion"""
    native_tokens_prompt: Nullable[float]
    r"""Native prompt tokens as reported by provider"""
    native_tokens_completion: Nullable[float]
    r"""Native completion tokens as reported by provider"""
    native_tokens_completion_images: Nullable[float]
    r"""Native completion image tokens as reported by provider"""
    native_tokens_reasoning: Nullable[float]
    r"""Native reasoning tokens as reported by provider"""
    native_tokens_cached: Nullable[float]
    r"""Native cached tokens as reported by provider"""
    num_media_prompt: Nullable[float]
    r"""Number of media items in the prompt"""
    num_input_audio_prompt: Nullable[float]
    r"""Number of audio inputs in the prompt"""
    num_media_completion: Nullable[float]
    r"""Number of media items in the completion"""
    num_search_results: Nullable[float]
    r"""Number of search results included"""
    origin: str
    r"""Origin URL of the request"""
    usage: float
    r"""Usage amount in USD"""
    is_byok: bool
    r"""Whether this used bring-your-own-key"""
    native_finish_reason: Nullable[str]
    r"""Native finish reason as reported by provider"""
    external_user: Nullable[str]
    r"""External user identifier"""
    api_type: Nullable[APIType]
    r"""Type of API used for the generation"""


class GetGenerationData(BaseModel):
    r"""Generation data"""

    id: str
    r"""Unique identifier for the generation"""

    upstream_id: Nullable[str]
    r"""Upstream provider's identifier for this generation"""

    total_cost: float
    r"""Total cost of the generation in USD"""

    cache_discount: Nullable[float]
    r"""Discount applied due to caching"""

    upstream_inference_cost: Nullable[float]
    r"""Cost charged by the upstream provider"""

    created_at: str
    r"""ISO 8601 timestamp of when the generation was created"""

    model: str
    r"""Model used for the generation"""

    app_id: Nullable[float]
    r"""ID of the app that made the request"""

    streamed: Nullable[bool]
    r"""Whether the response was streamed"""

    cancelled: Nullable[bool]
    r"""Whether the generation was cancelled"""

    provider_name: Nullable[str]
    r"""Name of the provider that served the request"""

    latency: Nullable[float]
    r"""Total latency in milliseconds"""

    moderation_latency: Nullable[float]
    r"""Moderation latency in milliseconds"""

    generation_time: Nullable[float]
    r"""Time taken for generation in milliseconds"""

    finish_reason: Nullable[str]
    r"""Reason the generation finished"""

    tokens_prompt: Nullable[float]
    r"""Number of tokens in the prompt"""

    tokens_completion: Nullable[float]
    r"""Number of tokens in the completion"""

    native_tokens_prompt: Nullable[float]
    r"""Native prompt tokens as reported by provider"""

    native_tokens_completion: Nullable[float]
    r"""Native completion tokens as reported by provider"""

    native_tokens_completion_images: Nullable[float]
    r"""Native completion image tokens as reported by provider"""

    native_tokens_reasoning: Nullable[float]
    r"""Native reasoning tokens as reported by provider"""

    native_tokens_cached: Nullable[float]
    r"""Native cached tokens as reported by provider"""

    num_media_prompt: Nullable[float]
    r"""Number of media items in the prompt"""

    num_input_audio_prompt: Nullable[float]
    r"""Number of audio inputs in the prompt"""

    num_media_completion: Nullable[float]
    r"""Number of media items in the completion"""

    num_search_results: Nullable[float]
    r"""Number of search results included"""

    origin: str
    r"""Origin URL of the request"""

    usage: float
    r"""Usage amount in USD"""

    is_byok: bool
    r"""Whether this used bring-your-own-key"""

    native_finish_reason: Nullable[str]
    r"""Native finish reason as reported by provider"""

    external_user: Nullable[str]
    r"""External user identifier"""

    api_type: Annotated[Nullable[APIType], PlainValidator(validate_open_enum(False))]
    r"""Type of API used for the generation"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = [
            "upstream_id",
            "cache_discount",
            "upstream_inference_cost",
            "app_id",
            "streamed",
            "cancelled",
            "provider_name",
            "latency",
            "moderation_latency",
            "generation_time",
            "finish_reason",
            "tokens_prompt",
            "tokens_completion",
            "native_tokens_prompt",
            "native_tokens_completion",
            "native_tokens_completion_images",
            "native_tokens_reasoning",
            "native_tokens_cached",
            "num_media_prompt",
            "num_input_audio_prompt",
            "num_media_completion",
            "num_search_results",
            "native_finish_reason",
            "external_user",
            "api_type",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetGenerationResponseTypedDict(TypedDict):
    r"""Generation response"""

    data: GetGenerationDataTypedDict
    r"""Generation data"""


class GetGenerationResponse(BaseModel):
    r"""Generation response"""

    data: GetGenerationData
    r"""Generation data"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .inputmodality import InputModality
from .modelgroup import ModelGroup
from .outputmodality import OutputModality
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import validate_open_enum
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


ModelArchitectureInstructType = Union[
    Literal[
        "none",
        "airoboros",
        "alpaca",
        "alpaca-modif",
        "chatml",
        "claude",
        "code-llama",
        "gemma",
        "llama2",
        "llama3",
        "mistral",
        "nemotron",
        "neural",
        "openchat",
        "phi3",
        "rwkv",
        "vicuna",
        "zephyr",
        "deepseek-r1",
        "deepseek-v3.1",
        "qwq",
        "qwen3",
    ],
    UnrecognizedStr,
]
r"""Instruction format type"""


class ModelArchitectureTypedDict(TypedDict):
    r"""Model architecture information"""

    modality: Nullable[str]
    r"""Primary modality of the model"""
    input_modalities: List[InputModality]
    r"""Supported input modalities"""
    output_modalities: List[OutputModality]
    r"""Supported output modalities"""
    tokenizer: NotRequired[ModelGroup]
    r"""Tokenizer type used by the model"""
    instruct_type: NotRequired[Nullable[ModelArchitectureInstructType]]
    r"""Instruction format type"""


class ModelArchitecture(BaseModel):
    r"""Model architecture information"""

    modality: Nullable[str]
    r"""Primary modality of the model"""

    input_modalities: List[
        Annotated[InputModality, PlainValidator(validate_open_enum(False))]
    ]
    r"""Supported input modalities"""

    output_modalities: List[
        Annotated[OutputModality, PlainValidator(validate_open_enum(False))]
    ]
    r"""Supported output modalities"""

    tokenizer: Annotated[
        Optional[ModelGroup], PlainValidator(validate_open_enum(False))
    ] = None
    r"""Tokenizer type used by the model"""

    instruct_type: Annotated[
        OptionalNullable[ModelArchitectureInstructType],
        PlainValidator(validate_open_enum(False)),
    ] = UNSET
    r"""Instruction format type"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["tokenizer", "instruct_type"]
        nullable_fields = ["instruct_type", "modality"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
